@@ -1,6 +1,6 @@
 use crate::Idx;
 use std::marker::PhantomData;
-use std::ops::{Range, RangeBounds};
+use std::ops::{Index, IndexMut, Range, RangeBounds};
 use std::{iter, slice, vec};
 
 #[derive(Clone, Debug, PartialEq, Eq, Hash)]
@@ -196,6 +196,22 @@ impl<I: Idx, T> IndexVec<I, T> {
     }
 }
 
+impl<I: Idx, T> Index<I> for IndexVec<I, T> {
+    type Output = T;
+
+    #[inline]
+    fn index(&self, index: I) -> &T {
+        &self.raw[index.index()]
+    }
+}
+
+impl<I: Idx, T> IndexMut<I> for IndexVec<I, T> {
+    #[inline]
+    fn index_mut(&mut self, index: I) -> &mut T {
+        &mut self.raw[index.index()]
+    }
+}
+
 pub type Enumerated<I, J> = iter::Map<iter::Enumerate<J>, IntoIdx<I>>;
 
 pub struct IntoIdx<I: Idx> {
